C
C *******1*********2*********3*********4*********5*********6*********7**
C
C     Subroutine MJD2ST
C
C     Converts Modified Julian Date into Sidereal Time for a given
C       observatory longitude.
C
C     Author: Michael Dumke (MPIfR), 16-Jan-2003
C
C     Input:  mjd     double precision Modified Julian Date
C             obslong double precision Observatory Longitude in deg (East > 0)
C     Output: gmst0   double precision Greenwich Mean Sidereal Time for UT=0
C             lst     double precision Local Sideral Time
C
C *******1*********2*********3*********4*********5*********6*********7**
C
      SUBROUTINE MJD2ST(MJD,OBSLONG,GMST0,LST)
C
      implicit none
      double precision mjd, obslong, gmst0, gast, lst, ut, njc,
     $                 year, mtagst
C
      ut = (mjd - dble(int(mjd))) * 24.d0
      njc = (int(mjd) - 51544.5)/36525.
      gmst0 = (24110.54841d0 + 8640184.812866d0*njc
     $     + 0.093104d0*njc*njc + 6.2d-6*njc**3)/3600.d0
      gmst0 = mod(24.d0+gmst0,24.d0)
C
C  Conversion from Greenwich Mean ST at UT=0 to Greenwich Apparent ST
C  based on fit to data from 1988 to 2002. M->A only for 1980-2020.
C
      year = (mjd - 51544.5d0)/365.25d0
c      if (abs(year).le.20.d0) then
c        mtagst = 1.0506d0*sin(9.34117d0*(year-6.34496d0))+0.03148d0
c      else
        mtagst = 0.d0
c      endif
C
      gast = gmst0 + mtagst/3600.d0 + ut*1.00273790935d0
      gast = mod(24.d0+gast,24.d0)
c
      lst = gast+obslong/15.
      lst = mod(lst+24.d0,24.d0)
      return
      end
C
C *******1*********2*********3*********4*********5*********6*********7**
