C
C *******1*********2*********3*********4*********5*********6*********7**
C
C     Subroutine ModJulDat
C
C     Computes the Modified Julian Date from Day, Month and Year.
C       MJD is JD-2400000.5, i.e. relative to 17-Nov-1858, 0:00 UT.
C       Does correct calculation for dates before 1582 (when the
C       calendar reform took place) as well.
C     Calculates also Julian Date and the number of days since
C       Jan 0th, 1900, 12:00 UT. Change the output parameter if
C       you need those.
C
C     Author: Michael Dumke (MPIfR), 16-Jan-2003
C
C     Input:  tag     double precision Current day (time as fraction)
C             inmonat integer          Current month
C             injahr  integer          Current year
C     Output: mjd     double precision Modified Julian Date
C
C *******1*********2*********3*********4*********5*********6*********7**
C
      subroutine MODJULDAT (TAG,INMONAT,INJAHR,MJD)
C
      implicit none
      integer inmonat, injahr, monat, jahr, schalt1, schalt2
      double precision tag, jd, mjd, jd1900, julorgreg
C
      if (inmonat.le.2) then
        monat = inmonat+12
        jahr = injahr-1
      else
        monat = inmonat
        jahr = injahr
      end if
C
      schalt1 = (365*jahr - 679004)
C
C  Check if Julian or Gregorian calendar is used (Year <> 1582):
C
      julorgreg = 1.d4*dble(jahr) + 1.d2*dble(monat) + tag
      if (julorgreg.LT.1.58210041d7) then
        schalt2 = int(((jahr+4716)/4)) - 1181
      else
        schalt2 = int(jahr/400) - int(jahr/100) + int(jahr/4)
      end if 
C
C  Calculate MJD, JD, and also JD1900 (# of days since 0-Jan-1900, 12 UT)
C
      mjd = schalt1 + schalt2 + dble(int(30.6001*(monat+1))) + tag
      jd = mjd + 2400000.5
      jd1900 = jd - 2415020.0
C
      return
      end
C
C *******1*********2*********3*********4*********5*********6*********7**
