C *******1*********2*********3*********4*********5*********6*********7**
C
C     Subroutine PARAL
C
C     Computes Azimuth, Elevation, Parallactic Angle, and their time
C        derivation in deg/hour for a given RA, Dec, and LST.
C
C     Author: H. Andernach (MPIfR), Oct-1984
C
C     Linux Version: M. Dumke (MPIfR), 14-Jan-2003
C
C     Input:  RA     double precision    Aight Ascencion in degrees
C             DEC    double precision    Declination in degrees
C             OBSLAT double precision    Latitide of observer in degrees
C             ST     double precision    LST in hours
C     Output: HA     double precision    Hour Angle
C             AZ     double precision    Azimuth (degrees)
C             AZV    double precision    dAZ/dTime
C             EL     double precision    Elevation (degrees)
C             ELVAR  double precision    dEl/dTime
C             Q      double precision    Parallactic Angle (degrees)
C             QV     double precision    dParAng/dTime
C
C *******1*********2*********3*********4*********5*********6*********7**
C
      subroutine paral (RA,DEC,OBSLAT,ST,HA,AZ,AZV,EL,ELVAR,Q,QV)
C
      implicit none
      double precision ra, dec, st, ha, az, azv, el, elvar, q, qv,
     $                 pi, rad2deg, sl, cl, had, sh, ch, sd, cd,
     $                 azz, azn, e, qz, qn, obslat, deg2rad
C
      pi = acos(-1.)
      rad2deg = 180./pi
      deg2rad = pi/180.
      sl = sin(deg2rad*obslat)
      cl = cos(deg2rad*obslat)
      had = (st*15.)-ra          
      ha = had/15.
      if (ha.gt.12.) ha = ha-24.
      if (ha.lt.-12.) ha = ha+24.
      ELVAR=0.0
      SH=SIN(deg2rad*HAD)           
      CH=COS(deg2rad*HAD)
      SD=SIN(deg2rad*DEC)           
      CD=COS(deg2rad*DEC)
      AZZ=-CD*SH             
      AZN=CL*SD-SL*CD*CH
      AZ = rad2deg*ATAN2(AZZ,AZN)
      IF(AZ.LT.0.0)AZ=AZ+360.
C DEFINE AZ(EAST)=90, AZ(SOUTH)=180, AZ(WEST)=270
      AZV=15.*(SL*CD*CD-CL*SD*CD*CH)/(AZZ*AZZ+AZN*AZN)
      E=SL*SD+CL*CD*CH       
      EL=rad2deg*ASIN(E)
      IF(SH.NE.0.0)ELVAR=-15.*CL*CD*SH/SQRT(1.0-E*E)
      QZ=CL*SH               
      QN=SL*CD-CL*SD*CH
      Q=rad2deg*ATAN2(QZ,QN)
      QV=15.*(SL*CL*CD*CH-CL*CL*SD)/(QN*QN+QZ*QZ)
      return
      end
C
C *******1*********2*********3*********4*********5*********6*********7**
