C *******1*********2*********3*********4*********5*********6*********7**
C
C     Subroutine READLINE
C
C     Reads and decodes an input line for Paral. Replaces the old
C       subroutine INSRC.
C
C     Author: M. Dumke (MPIfR), 20-Jan-2003
C             Changes: 21-Sep-2004 M. Dumke: Addition of Equinox
C
C     Input:  none
C     Output: catnam   character*8
C             RA8      real*8    Right Ascension in hours
C             DEC8     real*8    Declination in degrees
C             EQUINOX  integer   Equinox of position (1950 or 2000)
C             EPOCH(2) real*8(2) Epoch & Time Step (or Flux & Error)
C             ISTAT    integer   Error code (0 = no error)
C     
C -------1---------2---------3---------4---------5---------6---------7--
C
      subroutine readline (catnam, ra, dec, equinox, epoch, istat)
C
      implicit none
C
      integer leer, i, ih, im, ig, iam, idum, itimestep,
     $        istat, sign, equinox
      double precision ra, dec, sec, asec, epoch(2)
      logical nextline
      character*8 catnam
      character*80 zeile, rest
C
C  Initial assignment of variables
C
      istat = 0
      sign = 1
      epoch(1)=0.d0
      epoch(2)=0.d0
      RA=0.d0
      DEC=0.d0
      equinox=2000
      do 11 i=1,80
        zeile(i:i) = ' '
        rest(i:i) = ' '
   11 continue
      nextline = .TRUE.
      read(5,501) zeile
  501 format(a80)
      catnam = zeile(1:8)
      IF(catnam.EQ.'end') then
c     ***input of "end": return istat=2
        ISTAT=2
        return
      end if
      rest = zeile(9:80)
C
C  Forward until next character which is not SPACE or read next line
C
      zeile = rest
      call delspaces(zeile,idum,nextline)
      if (nextline) read(5,501) zeile
C
C  Read Right Ascension
C
      call readcoord(zeile, sign, ih, im, sec, rest,leer)
      ra = dble(sign) * (dble(ih) + (dble(im) + sec/60.d0)/60.d0)
      if (ra.lt.0.d0) ra = mod(ra+24.d0,24.d0)
      zeile = rest
      call delspaces(zeile,idum,nextline)
      if (nextline) read(5,501) zeile
C
C  Read Declination
C
      call readcoord(zeile, sign, ig, iam, asec, rest,leer)
      dec = dble(sign) * (dble(ig) + (dble(iam) + asec/60.d0)/60.d0)
      zeile = rest
      call delspaces(zeile,idum,nextline)
      if (nextline) read(5,501) zeile
C
C  Read Equinox
C
      call delspaces(zeile,idum,nextline)
      equinox = 2000
      if (.NOT.nextline) then
        read(zeile(1:4),514) equinox
      end if
  514 format(i4)
      rest = zeile(5:80)
C
C  Read epoch
C
      zeile = rest
      call delspaces(zeile,idum,nextline)
      epoch(1) = 0.d0
      if (.NOT.nextline) then
        if (idum.le.9) then
          istat = 1
          return
        end if
        read(zeile(1:9),510) epoch(1)
      end if
  510 format(f9.4)
      rest = zeile(10:80)
C
C  Read time step
C
      zeile = rest
      call delspaces(zeile,idum,nextline)
      if (nextline) read(5,501) zeile
      call delspaces(zeile,idum,nextline)
      itimestep = 0
      if (.NOT.nextline) then
        if (idum.EQ.2) read(zeile(1:1),511) itimestep
        if (idum.EQ.3) read(zeile(1:2),512) itimestep
        if (idum.EQ.4) read(zeile(1:3),513) itimestep
      end if
  511 format(i1)
  512 format(i2)
  513 format(i3)
      epoch(2) = dble(itimestep)
C
      end
C *******1*********2*********3*********4*********5*********6*********7**
C
C     Subroutine READCOORD
C
C     Reads astronomical coordinates from a string. Returns hours
C       (or degrees), (arc)minutes, (arc)seconds, and the remainder
C       of the string.
C     Recognizes hh:mm:ss.s, hh mm ss.s, h m s, h     m s.s etc.
C
C     Author: M. Dumke (MPIfR Bonn), 21-Jan-2003
C
C     Input:  inline  character*80     Input string
C     Output: sign    integer          +1 or -1: sign of coords
C             ihour   integer          hours or degrees
C             imin    integer          (arc)minutes
C             dsec    double precision (arc)seconds
C             outline character*80     Output string
C
C -------1---------2---------3---------4---------5---------6---------7--
C
      subroutine readcoord (inline, sign, ihour, imin, dsec,
     $                      outline, ierr)
C
      implicit none
      integer i, endindex, pointindex, ihour, imin, isec, accur, ierr,
     $        dum, sign
      double precision dsec
      logical empty, space, schonspace, point, schonpoint
      character*80 inline, outline, zeile, rest, sectext
C
      zeile = inline
      ierr = 0
      endindex = 0
      pointindex = 0
      space = .FALSE.
      schonspace = .FALSE.
      point = .FALSE.
      schonpoint = .FALSE.
      call delspaces(zeile,dum,empty)
C
C  If zeile is empty
C
      if (empty) then
        ierr = 1
        return
      end if
C
C  Check for sign
C
      sign = 1
      if (zeile(1:1).EQ.'+') then
         rest = zeile(2:80)
         zeile = rest
         call delspaces(zeile,dum,empty)
      else if (zeile(1:1).EQ.'-') then
         sign = -1
         rest = zeile(2:80)
         zeile = rest
         call delspaces(zeile,dum,empty)
      end if
         
      do i=1,2
        if ((zeile(2:2).EQ.' ').OR.(zeile(2:2).EQ.':')) then
          read(zeile(1:1),511) imin
          rest = zeile(3:80)
        else
          read(zeile(1:2),512) imin
          rest = zeile(4:80)
        end if
  511   format(i1)
  512   format(i2)
        if (i.EQ.1) ihour = imin
        if (rest(1:1).EQ.':') rest = rest(2:80)
        call delspaces(rest,dum,empty)
        zeile = rest
      end do
      do i=2,80
        if (zeile(i:i).EQ.' ') then
          space = .TRUE.
          if (.NOT.schonspace) endindex = i-1
          schonspace = .TRUE.
        end if
      end do
      sectext = zeile(1:endindex)
      do i=1,endindex
        if (zeile(i:i).EQ.'.') then
          point = .TRUE.
          if (.NOT.schonpoint) pointindex = i
          schonpoint = .TRUE.
        end if
      end do
C
C  Get rest of line for output
C
      outline = zeile(endindex+1:80)
C
C  If pointindex = 0, then sec is in integer:
C
      if (pointindex.EQ.0) then
        if (endindex.EQ.1) read(sectext(1:1),511) isec
        if (endindex.EQ.2) read(sectext(1:2),512) isec
        dsec = dble(isec)
C
C  otherwise its a real. Assume maximum accuracy ss.fff
C
      else
        accur = endindex - pointindex
        if (accur.EQ.0) read(sectext(1:endindex),610) dsec
        if (accur.EQ.1) read(sectext(1:endindex),611) dsec
        if (accur.EQ.2) read(sectext(1:endindex),612) dsec
        if (accur.GT.3) endindex = pointindex + 3
        if (accur.GE.3) read(sectext(1:endindex),613) dsec
      end if
  610 format(f3.0)
  611 format(f4.1)
  612 format(f5.2)
  613 format(f6.3)
      end
C
C *******1*********2*********3*********4*********5*********6*********7**
C
C     Subroutine DELSPACES
C
C     Deletes leading spaces from a character string
C
C     Author: M. Dumke (MPIfR Bonn), 17-Jan-2003
C
C     Input:  string    character*80 Input string
C     Output: string    character*80 Output string
C             firstnull integer      Position of first blank in output
C             empty     logical      .TRUE. if string empty
C
C -------1---------2---------3---------4---------5---------6---------7--
C
      subroutine delspaces(string,firstnull,empty)
C
      integer i, linestart, firstnull, leerstart
      logical empty, notspace, schontrue
      character*80 string, work

      notspace = .FALSE.
      schontrue = .FALSE.
      empty = .FALSE.
      work = string
      linestart = 1
      firstnull = 1
      do i=1,80
        if (work(i:i).NE.' ') then
          notspace = .TRUE.
          if (.NOT.schontrue) linestart = i
          schontrue = .TRUE.
        end if
      end do
C
      if (notspace) then
        string = work(linestart:80)
        leerstart = 82 - linestart
        do i=leerstart,80
          string(i:i) = ' '
        end do
        do i=1,80
          if (string(i:i).EQ.' ') then
            firstnull = i
            return
          end if
        end do
      else
        empty = .TRUE.
      endif
C
      end
C
C *******1*********2*********3*********4*********5*********6*********7**
C
C     Subroutine VALREAD
C
C     Reads a value from a string between leading spaces and first space
C       after the value.
C
C -------1---------2---------3---------4---------5---------6---------7--
C
      subroutine valread(instring,outint,outfrac,error)
C
      implicit none
C
      integer outint, fspace, error
      double precision outfrac
      logical empty
      character*80 instring, work
C
      work = instring
      call delspaces(work,fspace,empty)
      if (empty) then
        error = 1
        return
      end if
C
      end
C
C *******1*********2*********3*********4*********5*********6*********7**
