C *******1*********2*********3*********4*********5*********6*********7**
C
C     Subroutine RiseSet
C
C FOR A SOURCE AT RA AND DEC (BOTH IN DEGS.) OBSERVED AT GEOGR. LATITUDE
C OBSLAT THE RISING AND SETTING LST'S ARE COMPUTED FOR ELEVATION LIMIT
C ELLIM (I.E. ELLIM=0 IS THE MATHEMATICAL HORIZON)
C     
C     Author: H. Andernach (MPIfR), Oct-1984
C
C     Linux Version: M. Dumke (MPIfR), 14-Jan-2003
C
C     Input:  RA     double precision   Right Ascension in degrees
C             DEC    double precision   Declination in degrees
C             OBSLAT double precision   Latitude of observer in degrees
C             ELLIM  double precision   Elevation limit
C     Output: STRIS  double precision   Rise time
C             STSET  double precision   Set time
C
C *******1*********2*********3*********4*********5*********6*********7**
C
      subroutine riseset (RA,DEC,OBSLAT,ELLIM,STRIS,STSET)
C
      implicit none
      double precision ra, dec, obslat, ellim, stris, stset,
     $                 pi, rad2deg, deg2rad, sl, cl,
     $                 sd, cd, se, chr, haris
C
      pi = acos(-1.)
      rad2deg = 180./pi
      deg2rad = pi/180.
      sl = sin(deg2rad*obslat)
      cl = cos(deg2rad*obslat)
C
C     Case 1: circumpolar
C
      if (dec.ge.(90.d0-obslat+ellim)) then
        stris = 0.0
        stset = 24.0
        return
      end if
      sd = sin(deg2rad*dec)
      cd = cos(deg2rad*dec)
      se = sin(deg2rad*ellim)


      CHR=(SE-SL*SD)/CL/CD    
      IF(ABS(CHR).GT.1.)CHR=AINT(CHR)
      HARIS=rad2deg*ACOS(CHR)/15.
      STRIS=RA/15.-HARIS    
      STSET=RA/15.+HARIS
      IF(STRIS.LT. 0.0) STRIS=STRIS+24.0
      IF(STRIS.GT.24.0) STRIS=STRIS-24.0
      IF(STSET.LT. 0.0) STSET=STSET+24.0
      IF(STSET.GT.24.0) STSET=STSET-24.0
      RETURN     
      END
C
C *******1*********2*********3*********4*********5*********6*********7**
