########################################################################
#
#     TkParal
#
#     A Tcl/Tk based X-Window interface for the Paral program.
#
#     See the main script for copyright and version notices.
#
########################################################################
#
#     Subfile tkp_cats.tcl:
#     Procedure definitions for all catalog functions
#
#########1#########2#########3#########4#########5#########6#########7##
#
#   Procedure browseCat
#
#   Opens a source catalog via a FileBrowser window.
#   Supported Catalogs: .cat (OBS format, i.e. Effelsberg or 30-m)
#                       .cat (ARO format, i.e. KP 12-m or HHT)
#                       .cat (APEX format)
#                       .edb (XEphem format)
#                       .sou (Gildas format, i.e. Plateau de Bure)
#
proc browseCat { } {
    global defaultcatdir;
    set types {
        {"All Catalog Types" {.cat .sou .edb} }
        {"APEX, ARO & OBS Catalogs" {.cat} }
        {"Astro Catalogs" {.sou} }
        {"XEphem Catalogs" {.edb} }
    }
    set catfle [tk_getOpenFile \
        -initialdir $defaultcatdir \
        -filetypes $types \
        -title "Open a source catalog"];
    if { $catfle != "" } {
        displayCatalog $catfle;
    }
}
proc displayCatalog { fileName } {
    global schoncat;
    if { $schoncat == 1 } {
        set win .cat
    }
    if { $schoncat == 0 } {
        set win .cat
        toplevel $win
        wm title $win " Source selection from catalog ";
        frame $win.oben;
        listbox $win.t -width 72 -height 20 -bg #ddf \
            -yscroll "${win}.scroll set" \
            -selectmode single
        set sc [scrollbar ${win}.scroll -command "$win.t yview"]
        pack $win.t $sc -side left -in $win.oben -fill y
        frame $win.unten;
        button $win.load -text "Load Source" \
            -bg #ccf -border 3 -activebackground #ddf
        pack $win.load -side left -in $win.unten \
            -padx 5 -pady 3

        button $win.sel -text "Other Catalogs" -bg #ccf -border 3 \
            -activebackground #ddf -command browseCat
        button $win.b -text "Close Window" -bg #ccf -border 3 \
            -activebackground #ddf -command "zerstoer $win"
        pack $win.b $win.sel -side right -in $win.unten \
            -padx 5 -pady 3
        pack $win.oben $win.unten -side top -in $win -fill x
        set schoncat 1;
    }
    set infl [open $fileName r]
    $win.t delete 0 end;

    if { [string match "*.cat" [string tolower $fileName]] } {
        while { ![eof $infl] } {
            gets $infl sourceline1;
            set sourceline2 [string toupper [string trim $sourceline1]];
	    set sourceline [string map {"\"" " "} $sourceline2];
            if { [string index [lindex $sourceline 0] 0] != "!" } {
                if { ![string match "INDIVIDUAL*" $sourceline] \
                    && ![string match "COMMON*" $sourceline] \
                    && ![string match "STOP*" $sourceline] \
                    && ([string length $sourceline] != 0) } {
	            $win.t insert end $sourceline;
	        }
            }
        }
        close $infl
        bind $win.t <Double-Button-1> {
            prepareCatZeile [selection get];
        }
        bind $win.load <Button-1> {
            prepareCatZeile [selection get];
        }
    } elseif { [string match "*.edb" [string tolower $fileName]] } then {
        while { ![eof $infl] } {
            gets $infl sourceline1;
            set sourceline [string trim $sourceline1];
            if { [string index [lindex $sourceline 0] 0] != "#" \
                && ([string length $sourceline] != 0) } {
	        $win.t insert end $sourceline;
            }
        }
        close $infl
        bind $win.t <Double-Button-1> {
            prepareEdbZeile [selection get];
        }
        bind $win.load <Button-1> {
            prepareEdbZeile [selection get];
        }
    } elseif { [string match "*.sou" [string tolower $fileName]] } {
        while { ![eof $infl] } {
            gets $infl sourceline1;
	    set sourceline [string map {"\"" " "} [string trim $sourceline1]];
            if { [string index [lindex $sourceline 0] 0] != "!" \
                && ([string length $sourceline] != 0) } {
	        $win.t insert end $sourceline;
            }
        }
        close $infl
        bind $win.t <Double-Button-1> {
            prepareSouZeile [selection get];
        }
        bind $win.load <Button-1> {
            prepareSouZeile [selection get];
        }
    }
    $win.t selection set 0 0;
}
proc prepareCatZeile { seloutput1 } {
    global sname chour cmin csec cdeg camin casec;
    set seloutput [string toupper $seloutput1];
    set plumpaquatsch [string first "SNAM=" $seloutput];
    set snamstart [expr $plumpaquatsch + 5]
    if { $plumpaquatsch == -1 } {
        set plumpaquatsch [string first "SNAM =" $seloutput];
        set snamstart [expr $plumpaquatsch + 6]
    }
    if { $plumpaquatsch == -1 } {
        set plumpaquatsch [string first "SNAM" $seloutput];
        set snamstart [expr $plumpaquatsch + 4]
    }
    if { $plumpaquatsch == -1 } {
    # no SNAM keyword --> .cat file is ARO or APEX catalog
        set indicator [lindex $seloutput 2];
        if { ![string match "J2000.0" $indicator] \
            && ![string match "B1950.0" $indicator] } {
            # no Equinox like these --> .cat file is not ARO catalog
            prepareSouZeile $seloutput
        } else {
            prepareAROZeile $seloutput
        }
    } else {
        prepareOBSZeile $seloutput $snamstart
    }
}
proc prepareOBSZeile { seloutput snamstart } {
   global sname chour cmin csec cdeg camin casec;
   set snamend [expr [string first ";" $seloutput $snamstart] - 1];
   set sname [string trim [string range $seloutput $snamstart $snamend]];
   set rastart [expr [string first "SLAM=" $seloutput] + 5];
   if { $rastart == 4 } {
      set rastart [expr [string first "SL0P=" $seloutput] + 5];
   }
   if { $rastart == 4 } {
      set rastart [expr [string first "SLAM =" $seloutput] + 6]
   }
   if { $rastart == 5 } {
      set rastart [expr [string first "SLAM" $seloutput] + 4]
   }
   if { $rastart == 3 } {
      set rastart [expr [string first "SL0P =" $seloutput] + 6]
   }
   if { $rastart == 5 } {
      set rastart [expr [string first "SL0P" $seloutput] + 4]
   }
   set raend [expr [string first ";" $seloutput $rastart] - 1];
   set ra [string trim [string range $seloutput $rastart $raend]];
   if { [string tolower [string index $ra end]] == "s" } {
      set ra [string trim [string range $ra 1 end-1]];
   }
   set chour [lindex $ra 0];
   set cmin [lindex $ra 1];
   set csec [lindex $ra 2];
   set decstart [expr [string first "SBET=" $seloutput] + 5];
   if { $decstart == 4 } {
      set decstart [expr [string first "SB0P=" $seloutput] + 5];
   }
   if { $decstart == 4 } {
      set decstart [expr [string first "SBET =" $seloutput] + 6]
   }
   if { $decstart == 5 } {
      set decstart [expr [string first "SBET" $seloutput] + 4]
   }
   if { $decstart == 3 } {
      set decmstart [expr [string first "SB0P =" $seloutput] + 6]
   }
   if { $decstart == 5 } {
      set decstart [expr [string first "SB0P" $seloutput] + 4]
   }
   set decend [expr [string first ";" $seloutput $decstart] - 1];
   if { $decend == -2 } {
      set decend [string length $seloutput];
   }
   set dec [string trim [string range $seloutput $decstart $decend]];
   set cdeg [lindex $dec 0];
   set camin [lindex $dec 1];
   set casec [lindex $dec 2];
   selectEqError;
}
proc prepareAROZeile { seloutput } {
   global sname chour cmin csec cdeg camin casec;
   set sname [lindex $seloutput 3];
   set ra [lindex $seloutput 0];
   set dec [lindex $seloutput 1];
   set rahend [expr [string first ":" $ra] - 1];
   set chour [string range $ra 0 $rahend];
   set cmin [string range $ra [expr $rahend + 2] [expr $rahend + 3]];
   set csec [string range $ra [expr $rahend + 5] end];
   set decdend  [expr [string first ":" $dec] -1];
   set cdeg [string range $dec 0 $decdend];
   set camin [string range $dec [expr $decdend + 2] [expr $decdend + 3]];
   set casec [string range $dec [expr $decdend + 5] end];
   if { [string match *1950*  [lindex $seloutput 2]] } {
      setequinox 0;
   } elseif { [string match *2000* [lindex $seloutput 2]] } {
      setequinox 1;
   } else {
      selectEqError;
   }
}
proc prepareEdbZeile { seloutput1 } {
   global sname chour cmin csec cdeg camin casec;
   set seloutput [string toupper $seloutput1];
   set snamstart 0;
   set snamend [expr [string first "," $seloutput $snamstart] - 1]
   set sname [string trim [string range $seloutput $snamstart $snamend]];
   set rastart [expr [string first "," $seloutput [expr $snamend + 2]] + 1];
   set raend [expr [string first "," $seloutput $rastart] - 1];
   set ra [string trim [string range $seloutput $rastart $raend]];
   set rahend [expr [string first ":" $ra] - 1];
   set chour [string range $ra 0 $rahend];
   set cmin [string range $ra [expr $rahend + 2] [expr $rahend + 3]];
   set csec [string range $ra [expr $rahend + 5] end];
   set decstart [expr [string first "," $seloutput $raend] + 1];
   set decend [expr [string first "," $seloutput $decstart] - 1];
   set dec [string trim [string range $seloutput $decstart $decend]];
   set decdend  [expr [string first ":" $dec] -1];
   set cdeg [string range $dec 0 $decdend];
   set camin [string range $dec [expr $decdend + 2] [expr $decdend + 3]];
   set casec [string range $dec [expr $decdend + 5] end];
   set indicator [string trim [string range $seloutput [expr $decend +2] end]]
   if { [string match *1950* $indicator] } {
      setequinox 0;
   } elseif { [string match *2000* $indicator] } {
      setequinox 1;
   } else {
      selectEqError;
   }
}
proc prepareSouZeile { seloutput1 } {
   global sname chour cmin csec cdeg camin casec;
   set seloutput [string trim [string toupper $seloutput1]];
   set sname [lindex $seloutput 0];
   set eq [string toupper [string range [lindex $seloutput 1] 0 end]];
   if { $eq == "EQ" } {
      set ra [lindex $seloutput 3];
      set dec [lindex $seloutput 4];
      if { [string match *1950* [lindex $seloutput 2]] } {
         setequinox 0;
      } elseif { [string match *2000* [lindex $seloutput 2]] } {
         setequinox 1;
      } else {
         selectEqError;
      }
   } elseif { $eq == "DA" } {
      set ra [lindex $seloutput 2];
      set dec [lindex $seloutput 3];
      openErrorMess 1;
   } elseif { [string match *:* $eq] || [string match *.* $eq] } {
      set ra [lindex $seloutput 1];
      set dec [lindex $seloutput 2];
      selectEqError;
   } else {
      openErrorMess 2;
      return;
   }
   set rahend [expr [string first ":" $ra] - 1];
   set chour [string range $ra 0 $rahend];
   set cmin [string range $ra [expr $rahend + 2] [expr $rahend + 3]];
   set csec [string range $ra [expr $rahend + 5] end];
   set decdend  [expr [string first ":" $dec] -1];
   set cdeg [string range $dec 0 $decdend];
   set camin [string range $dec [expr $decdend + 2] [expr $decdend + 3]];
   set casec [string range $dec [expr $decdend + 5] end];
}
proc selectEqError { } {
    global equinoxtext;
    if { [string compare $equinoxtext "B1950.0"] } {
        openErrorMess 0;
    } else {
        openErrorMess 1;
    }
}
proc openErrorMess { number } {
   global durchlaeufe;
   if { $durchlaeufe == 0 } {
      openTabelle
   }
   incr durchlaeufe ;
   if { $number == 0 } {
      .entlog insert end " The position of the selected source may be in\
              equatorial coordinates, \n" ;
      .entlog insert end " but the epoch could not be detected. \n" ;
      .entlog insert end " Please select it manually\
              (otherwise we assume J2000.0) ! \n" ;
   }
   if { $number == 1 } {
      .entlog insert end " The position of the selected source may be in\
              equatorial coordinates, \n" ;
      .entlog insert end " but the epoch could not be detected. \n" ;
      .entlog insert end " Please select it manually\
              (otherwise we assume B1950.0) ! \n" ;
   }
   if { $number == 2 } {
      .entlog insert end " The coordinate system of the chosen source\
              is not equatorial, \n" ;
      .entlog insert end " thus you cannot use PARAL. \n" ;
      .entlog insert end " Choose another source, or enter the\
              correct equatorial coordinates by hand ! \n" ;
   }
}
