########################################################################
#
#     TkParal
#
#     A Tcl/Tk based X-Window interface for the Paral program.
#
#     See the main script for copyright and version notices.
#
########################################################################
#
#   Do not run this script directly! Run "tkparal" instead, which sets
#   some important variables and then calls this script.
#
#   If you want to change the location of the Paral executable,
#   please do it here (this is the ONLY line you may have to edit):
#
set paral_exe $tkp_sourcedir/main/paral
#     
# Mainfile: Create the GUI
#

set durchlaeufe 0
set schonhelp 0
set schonabout 0
set schoncat 0

source $tkp_sourcedir/tcltk/tkp_lists.tcl
source $tkp_sourcedir/tcltk/tkp_procs.tcl
source $tkp_sourcedir/tcltk/tkp_cats.tcl

################################################################
#
# Main Window & Menu Bar
#
wm title . "TkParal V1.41"

frame .mnb -relief raised -borderwidth 1
menubutton .mnb.file -text "File" -underline 0 -relief raised -width 8 \
	   -menu .mnb.file.1

set fle [menu .mnb.file.1]
#$fle add command -label "Load current" -command "OpenFile"
#$fle add command -label "Save" -command "SaveFile"
$fle add command -label "Quit TkParal" -command "ExitParal"

label .mnb.warning -text "X Window Interface for Paral"
pack .mnb.file -side left -fill x -in .mnb
pack .mnb.warning -expand 1 -side left -fill x -in .mnb

menubutton .mnb.help -text "Help" -underline 0 -relief raised -width 8 \
	   -menu .mnb.help.1
set hlp [menu .mnb.help.1]
$hlp add command -label "Help" -command "displayTextFile \
       [file join $tkp_sourcedir/tcltk tkp_help.txt]"
$hlp add command -label "About" -command "displayTextFile \
       [file join $tkp_sourcedir/tcltk tkp_about.txt]"

#menu .mnb.help.1
#foreach n [count 0 2] page [list Help About] {
#   .mnb.help.1 add command -label $page -command "displayHtmlFile \
#       [file join $tkparal_dir [string tolower $page].html]"
#}

pack .mnb.help -side right -fill x -in .mnb
pack .mnb -fill x

################################################################
#
# Choose Observatory
#
frame .obs -height 2c -borderwidth 1
pack .obs -padx 5 -pady 5

label .obs.lab -text "Observatory:"
set obstext "Observatory" ;
menubutton .obs.men -textvariable obstext -relief raised \
	   -width 20 -menu .obs.men.1
set ftst [menu .obs.men.1]
for {set tel 0} {$tel<[llength $obs_list]} {incr tel} { 
   $ftst add command -label [lindex $obs_list $tel] \
      -command "setobs $tel"
}
label .obs.longl -text "Longitude:"
entry .obs.long -textvariable obslong -width 8 ;
label .obs.latl -text "Latitude:"
entry .obs.lat -textvariable obslat -width 8 ;

pack .obs.lab .obs.men .obs.longl .obs.long .obs.latl .obs.lat \
     -in .obs -side left -padx 3 -pady 3 -ipadx 2 -ipady 2

################################################################
#
# Line with source parameters
#
frame .zeile -height 2c -borderwidth 1
pack .zeile -padx 5 -pady 5
label .zeile.n1 -text "Source:"
entry .zeile.n2 -textvariable sname -width 8
label .zeile.ra1 -text "RA:"
entry .zeile.rah -textvariable chour -width 2
entry .zeile.ram -textvariable cmin -width 2
entry .zeile.ras -textvariable csec -width 5
label .zeile.de1 -text "Dec:"
entry .zeile.ded -textvariable cdeg -width 3
entry .zeile.deam -textvariable camin -width 2
entry .zeile.deas -textvariable casec -width 4
set equinoxtext "Equinox" ;
menubutton .zeile.e -textvariable equinoxtext -relief raised \
	   -width 6 -menu .zeile.e.1
set emen [menu .zeile.e.1]
for {set equinox 0} {$equinox<[llength $equinox_list]} {incr equinox} { 
   $emen add command -label [lindex $equinox_list $equinox] \
      -command "setequinox $equinox"
}
button .zeile.cat -text "Catalogs" -bg #ccf -border 3 \
       -activebackground #ddf -padx 3 -command browseCat

pack .zeile.n1 .zeile.n2 .zeile.ra1 .zeile.rah .zeile.ram .zeile.ras \
     .zeile.de1 .zeile.ded .zeile.deam .zeile.deas .zeile.e .zeile.cat \
     -in .zeile -padx 3 -pady 3 -ipadx 2 -ipady 2 -side left

################################################################
#
# Line with observing date and time step
#
frame .zeile2 -height 2c
pack .zeile2 -padx 5 -pady 3
label .zeile2.n1 -text "Observing date:"

set datestring [exec date] ;

set year [lsearch $year_list [lindex $datestring end]] ;
setyear $year ;
menubutton .zeile2.y -textvariable yeartext -relief raised \
	   -width 5 -menu .zeile2.y.1
set ymen [menu .zeile2.y.1]
for {set year 0} {$year<[llength $year_list]} {incr year} { 
   $ymen add command -label [lindex $year_list $year] \
      -command "setyear $year"
}

set month [lsearch $month_list [lindex $datestring 1]] ;
if { $month == -1 } {
   set month [lsearch $dmonth_list [lindex $datestring 1]]
}
setmonth $month ;
menubutton .zeile2.m -textvariable monthtext -relief raised \
	   -width 5 -menu .zeile2.m.1
set mmen [menu .zeile2.m.1]
for {set month 0} {$month<12} {incr month} { 
   $mmen add command -label [lindex $month_list $month] \
      -command "setmonth $month"
}

set day [lindex $datestring 2] ;
setday $day ;
menubutton .zeile2.d -textvariable daytext -relief raised \
	   -width 5 -menu .zeile2.d.1
set dmen [menu .zeile2.d.1]
for {set day 1} {$day<32} {incr day} { 
   $dmen add command -label $day -command "setday $day"
}

label .zeile2.stl -text "Time step (minutes):"
entry .zeile2.ste -textvariable step -width 2
pack .zeile2.n1 .zeile2.y .zeile2.m .zeile2.d .zeile2.stl \
     .zeile2.ste -in .zeile2 -side left -padx 3 -pady 3 -ipadx 1 -ipady 1 
set step 30

################################################################
#
# Buttons:
#
frame .bf
pack .bf -padx 5 -pady 5 -ipadx 4 -ipady 4 -fill x

button .bf.run -text "Run Paral" -bg #bbc -border 3 \
       -activebackground #ccd -command invokeParal
button .bf.clear -text "Clear Source" -bg #bbc -border 3 \
       -activebackground #ccd -command clearEntries
#button .bf.quit -text "Quit" -command {exit}

pack .bf.run .bf.clear -side left \
     -in .bf -padx 1 -pady 1 -ipadx 1 -ipady 1

################################################################
#
# Finalize:
#
focus .zeile.n2 ;
pack .mnb .obs .zeile .zeile2 .bf -side top -fill x

#
# Finished :-)
#
################################################################
