########################################################################
#
#     TkParal
#
#     A Tcl/Tk based X-Window interface for the Paral program.
#
#     See the main script for copyright and version notices.
#
########################################################################
#
# Subfile tkp_procs.tcl: Procedure definitions
#
proc ExitParal { } {
   if {[file exists "p_out"]} {
      exec rm p_out
   }
   exit
}
proc SaveFile { } {
   set types {
      {"Paral Output" {.prl} }
   }
   global env;
   set fle [tk_getSaveFile -initialdir $env(HOME) -filetypes $types \
	    -initialfile default.prl -defaultextension .prl \
            -title "Save the output table(s) to a file"];
   set flebak $fle~;
   if {[file exists "$fle"]} {
      if {[file exists "$flebak"]} {
         exec rm $flebak
      }
      exec cp $fle $flebak
   }
   set sts [catch {set f [open $fle w]} errormessage]
   if {$sts == 0} {
      puts $f [.entlog get 1.0 end];
      flush $f;
      close $f;
   }
}
proc setequinox {equinox} {
    global eq equinoxtext equinox_list ;
    set equinoxtext [lindex $equinox_list $equinox]
    set eq [string range $equinoxtext 1 4] ;
}
proc setyear {year} {
    global obsy yeartext year_list ;
    set obsy [lindex $year_list $year] ;
    set yeartext $obsy
}
proc setmonth {month} {
    global obsm monthtext month_list ;
    set monthtext [lindex $month_list $month]
    set obsm [format %02.2s [incr month]] ;
}
proc setday {day} {
    global obsd daytext ;
    set obsd [format %02.2s $day] ;
    set daytext $day ;
}
proc setobs {tel} {
    global obstext obs_list obslong obslat longitude_list latitude_list;
    set obstext [lindex $obs_list $tel] ;
    set obslong [lindex $longitude_list $tel] ;
    set obslat [lindex $latitude_list $tel] ;
}
proc clearEntries { } {
    foreach e { .zeile.n2 .zeile.rah .zeile.ram \
       .zeile.ras .zeile.ded .zeile.deam .zeile.deas } {
       $e delete 0 end
    }
}
proc createZeile { } {
   global paralzeile sname chour cmin csec cdeg camin casec \
	  equinoxtext eq obsy obsm obsd step ;
   if { [string compare $sname ""] == 0 } {
      set sname DUMMY
   }
   if { [string compare $chour ""] == 0 } {
      set chour 0
   }
   if { [string compare $cmin ""] == 0 } {
      set cmin 0
   }
   if { [string compare $csec ""] == 0 } {
      set csec 0
   }
   if { [string compare $cdeg ""] == 0 } {
      set cdeg 0
   }
   if { [string compare $cdeg "+"] == 0 } {
      set cdeg 0
   }
   if { [string compare $cdeg "-"] == 0 } {
      set cdeg 0
   }
   if { [string compare $camin ""] == 0 } {
      set camin 0
   }
   if { [string compare $casec ""] == 0 } {
      set casec 0
   }
   if { [string compare $equinoxtext "Equinox"] == 0 } {
      setequinox 1
   }
   if { $step ==  0 } {
      set step 1
   }
   set paralzeile "[format %-8.8s $sname] [format %2.2s $chour]\
      [format %2.2s $cmin] [format %4.4s $csec] [format %3.3s $cdeg]\
      [format %2.2s $camin] [format %-4.4s $casec]\
      [format %4.4s $eq]\
      [format %9.9s $obsy.$obsm$obsd]\
      [format %2.3s $step]"
}
proc invokeParal { } {
   createZeile
   global durchlaeufe f paralzeile obstext obslong obslat cdeg eq paral_exe ;
   if { [string compare $obslong ""] == 0 } {
      set obslong 0.0
   }
   if { [string compare $obslat ""] == 0 } {
      set obslat 0.0
   }
   if { $durchlaeufe == 0 } {
      openTabelle
   }
   incr durchlaeufe ;
   if { [string index $cdeg end-1] == 0 } {
      set cdeg [string map {08 8 09 9} $cdeg]
   }
   if { abs($obslat-$cdeg) > 82 } {
      .entlog insert end " This source is not visible at the chosen\
              observatory: \n" ;
      .entlog insert end " Elv < 8 deg at all times ! \n\n" ;
      .entlog insert end " Please try again ! \n\n" ;
      return
   }
   set f [open |$paral_exe r+] ;
   puts $f $obslat
   flush $f
   puts $f $obslong
   flush $f
   puts $f $paralzeile
   flush $f ;
   puts $f "end"
   flush $f ;
   .entlog insert end "\n" ;
   .entlog insert end " Data for $obstext \n" ;
   gets $f tabelle ;
   set anfang [string range $tabelle 1 10] ;
   while { $anfang != "----------" } {
      gets $f tabelle ;
      set anfang [string range $tabelle 1 10]
   }
   while { $anfang != " Latitude " } {
      .entlog insert end $tabelle ;
      .entlog insert end "\n" ;
      gets $f tabelle ;
      set anfang [string range $tabelle 1 10]
   }
}
proc openTabelle { } {
   button .bf.clout -text "Clear Output" -bg #bbc -border 3 \
       -activebackground #ccd -command clearTabelle
   button .bf.save -text "Save Output" -bg #bbc -border 3 \
       -activebackground #ccd -command SaveFile
   pack .bf.clout .bf.save -side right \
	-in .bf -padx 1 -pady 1 -ipadx 1 -ipady 1
   frame .log -relief sunken -borderwidth 1 -width 10c -height 5c 
   pack .log
   text .entlog -width 80 -height 30 -yscrollcommand ".ys set" \
        -bg #ded -padx 10 -pady 10
   scrollbar .ys -command ".entlog yview"
   pack .entlog .ys -in .log -side left -fill y
}
proc clearTabelle { } {
   .entlog delete 1.0 end
}
################################################################
#
# proc displayTextFile: Opens a new toplevel window and displays file
#
proc displayTextFile { fileName } {
   global schonabout schonhelp ;
   if { [string match "*about*" $fileName] } {
      if { $schonabout == 1 } {
         return
      } else {
         set schonabout 1
         set win .about
      }
   }
   if { [string match "*help*" $fileName] } {
      if { $schonhelp == 1 } {
         return
      } else {
         set schonhelp 1
         set win .help
      }
   }
   toplevel $win
   set t [text $win.t -padx 10 -pady 10 -bg #ddf \
       -yscrollcommand "${win}.scroll set"]
   set sc [scrollbar ${win}.scroll -command "$t yview"]

   set r 0
   grid $t -row $r -column 0 -sticky news
   grid $sc -row $r -column 1 -sticky ns
   grid rowconfigure $win $r -weight 10
   grid columnconfigure $win 0 -weight 10


   set infl [open $fileName r]
   while { ![eof $infl] } {
      $win.t insert end [read $infl 100]
   }
   close $infl

   button $win.b -text "Close Window" -command "zerstoer $win"
   grid $win.b -row 2 -column 0
}
proc zerstoer { fenster } {
   global schonabout schonhelp schoncat;
   if { $fenster == ".help" } {
      destroy $fenster ;
      set schonhelp 0
   }
   if { $fenster == ".about" } {
      destroy $fenster ;
      set schonabout 0
   }
   if { $fenster == ".cat" } {
      destroy $fenster ;
      set schoncat 0
   }
}
